disp('Wall with uniform source load (128-b)');
graphics =~0;
L=6;
kappa=4;
Q =.1;% 
n=7; % number of elements
% Mesh
[fens,gcells]= block1d(L,n, 1.0);
% Finite element block
prop=property_diffusion(struct('conductivity',kappa,'source',Q));
mater=mater_diffusion (struct('property',prop));
feb = feblock_diffusion (struct (...
    'mater',mater,...
    'gcells',gcells,...
    'integration_rule',gauss_rule(1,2)));
geom = field(struct ('name',['geom'], 'dim', 1, 'fens',fens));
tempn = field(struct ('name',['temp'], 'dim', 1,...
    'nfens',get(geom,'nfens')));
Fenids=[1,length(fens)];
tempn = set_ebc(tempn, Fenids, Fenids*0+1, Fenids*0+1, Fenids*0);
tempn = apply_ebc (tempn);
tempn = numbereqns (tempn);
 

% Assemble the system matrix
K = start (sparse_sysmat, get(tempn, 'neqns'));
K = assemble (K, conductivity(feb, geom, tempn));
% Load
F = start (sysvec, get(tempn, 'neqns'));
F = assemble (F, source_loads(feb, geom, tempn));
% Solve
tempn = scatter_sysvec(tempn, K\F);
% Plot
if (graphics)
    figure; hold on;
    pc=linspace(-1,+1,100);
    for j=1:length(gcells)
        ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
        iw=isoparamipol1d(gcells(j),pc,gather(tempn,get(gcells(j),'conn'),'values'));
        plot(ix/L,(kappa/Q/L^2)*iw,'r-','linewidth',3);hold on
    end
    x=(pc+1)/2*L;
    plot(x/L,(kappa/Q/L^2)*Q/(2*kappa)*x.*(L-x),'k:','linewidth',3);hold on
    xlabel('x/L'),ylabel('(\kappa/Q/L^2)*T')
    
    figure; hold on;
    pc=linspace(-1,+1,100);
    for j=1:length(gcells)
        ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
        iw=isoparamipol1d(gcells(j),pc,gather(tempn,get(gcells(j),'conn'),'values'));
        x=ix;
        plot(ix/L,(kappa/Q/L^2)*Q/(2*kappa)*x.*(L-x)-(kappa/Q/L^2)*iw,'r-','linewidth',3);hold on
    end
    xlabel('x/L'),ylabel('(\kappa/Q/L^2)*(T_{ex}-T)')
    
    figure; hold on;
    pc=linspace(-1,+1,10);
    for j=1:length(gcells)
        ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
        iwp=isoparamipol1ddersp(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'),gather(tempn,get(gcells(j),'conn'),'values'));
        plot(ix/L,-kappa*iwp,'r-','linewidth',3);hold on
    end
    x=(pc+1)/2*L;
    plot(x/L,-kappa*Q/2/kappa*(L-2*x),'k:','linewidth',3);hold on
    xlabel('x/L'),ylabel('q')

    figure; hold on;
    pc=linspace(-1,+1,10);
    for j=1:length(gcells)
        ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
        iwp=isoparamipol1ddersp(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'),gather(tempn,get(gcells(j),'conn'),'values'));
        x=ix;
        plot(ix/L,-kappa*Q/2/kappa*(L-2*x)-(-kappa*iwp),'r-','linewidth',3);hold on
    end
%     left_handed_axes;% Plotting is consistent with the textbook sign convention
    xlabel('x/L'),ylabel('q_{ex}-q')
end

