kappa=[1.8 0; 0 1.8]; % conductivity matrix
Q=4.5; % uniform heat source
ho= 5.2; % watts per meter square per degree Kelvin
R=2.5;
To=-1.5; % ambient temperature next to outer surface
num_integ_pts=3; %  quadrature
fens = [fenode(struct('id',1,'xyz',[0,0]));...
    fenode(struct('id',2,'xyz',[R*cos(0*pi/180),R*sin(0*pi/180)]));...
    fenode(struct('id',3,'xyz',[R*cos(45*pi/180),R*sin(45*pi/180)]));...
    fenode(struct('id',4,'xyz',[R/2*cos(0*pi/180),R/2*sin(0*pi/180)]));...
    fenode(struct('id',5,'xyz',[R*cos(45/2*pi/180),R*sin(45/2*pi/180)]));...
    fenode(struct('id',6,'xyz',[R/2*cos(45*pi/180),R/2*sin(45*pi/180)]));...
    ];
gcells = [gcell_T6(struct('id',1,'conn',[1,2,3,4,5,6],'other_dimension', 1))];
bgcells = [gcell_L3(struct('id',1,'conn',[2,3,5],'other_dimension', 1))];
prop=property_diffusion(struct('conductivity',kappa,'source',Q));
mater=mater_diffusion (struct('property',prop));
feb = feblock_diffusion (struct ('mater',mater,...
    'gcells',gcells,...
    'integration_rule',tri_rule(num_integ_pts)));
efeb = feblock_diffusion (struct ('mater',mater,...
    'gcells',bgcells,...
    'integration_rule',gauss_rule(1,2),'surface_transfer', ho));
geom = field(struct('name',['geom'], 'dim', 2, 'fens',fens));
theta=field(struct('name',['theta'], 'dim', 1, 'nfens',...
    get(geom,'nfens')));
theta = numbereqns (theta);
oamb = clone(theta, ['oamb']);
fenids=[2,3,5];
prescribed=ones(length(fenids),1);
comp=[];
val=zeros(length(fenids),1)+To;
oamb = set_ebc(oamb, fenids, prescribed, comp, val);
oamb = apply_ebc (oamb);
K = start (sparse_sysmat, get(theta, 'neqns'));
K = assemble (K, conductivity(feb, geom, theta));
K = assemble (K, surface_transfer(efeb, geom, theta));
F = start (sysvec, get(theta, 'neqns'));
F = assemble (F, source_loads(feb, geom, theta));
F = assemble (F, surface_transfer_loads(efeb, geom, theta, oamb));

theta = scatter_sysvec(theta, get(K,'mat')\get(F,'vec'));
% Plot
gv=graphic_viewer;
gv=reset (gv,[]);
T=get(theta,'values');
dcm=data_colormap(struct('range',[min(T),max(T)],'colormap',hot));
colorfield=field(struct ('name', ['colorfield'], 'data',...
    map_data(dcm, T)));
geomT=field(struct ('name', ['geomT'], ...
    'data',[get(geom,'values'), get(theta,'values')]));
for i=1:length (gcells)
    draw(gcells(i), gv, struct ('x',geomT, 'u',0*geomT,...
        'colorfield',colorfield, 'shrink',1.0));
    draw(gcells(i), gv, struct ('x',geom, 'u',0*geom, ...
        'facecolor','none'));
end
axis equal vis3d
set(gca,'DataAspectRatio', [1, 1, 4*(max(T)/R)])
zlabel('Temperature [degree Celsius]')
(get(theta,'values'))