kappa=[52 0; 0 52]; % conductivity matrix
Q=0.0; % uniform heat source
h=750;
graphics=1;
Mesh_options =struct('quadratic',true);
Targetnel=700;
convergence_rate=1.5;
Region_definition={'REGEXT 0 0 0.6 1.0',...
    ['curve 1 line 0 0 0.6 0'],...
    ['curve 2 line 0.6 0 0.6 0.2'],...
    ['curve 3 line 0.6 0.2 0.6 1.0'],...
    ['curve 4 line 0.6 1.0 0 1.0'],...
    ['curve 5 line 0 1.0 0 0'],...
    ['subregion 1  property 1 boundary 1 2 3 4 5']};

mesh_size=0.125;
[fens,gcells,groups,edge_gcells,edge_groups]...
    =targe2_mesher(cat(2,Region_definition,{['m-ctl-point constant ' num2str(mesh_size)]}), 1.0, Mesh_options);

for Adapt=1:5
    
    length(gcells)
    
    prop=property_diffusion(struct('conductivity',kappa,'source',Q));
    mater=mater_diffusion (struct('property',prop));
    feb = feblock_diffusion (struct ('mater',mater,...
        'gcells',gcells,...
        'integration_rule',tri_rule(3)));
    edgefeb = feblock_diffusion (struct ('mater',mater,...
        'gcells',edge_gcells([edge_groups{[2, 3, 4]}]),...
        'integration_rule',gauss_rule(1,3),...
        'surface_transfer', h));
    geom = field(struct('name',['geom'], 'dim', 2, 'fens',fens));
    theta=field(struct('name',['theta'], 'dim', 1, 'nfens',...
        get(geom,'nfens')));
    amb = clone(theta, ['amb']);
    fenids=[
        fenode_select(fens,struct('box',[0.6 0.6 0 1],...
        'inflate', 1e-7)),...
        fenode_select(fens,struct('box',[0 1 1 1],...
        'inflate', 1e-7))]   ;
    prescribed=ones(length(fenids),1);
    comp=[];
    val=zeros(length(fenids),1)+0.0;
    amb = set_ebc(amb, fenids, prescribed, comp, val);
    amb = apply_ebc (amb);
    fenids=[
        fenode_select(fens,struct('box',[0. 0.6 0 0],...
        'inflate', 1e-7))]    ;
    prescribed=ones(length(fenids),1);
    comp=[];
    val=zeros(length(fenids),1)+100.0;
    theta = set_ebc(theta, fenids, prescribed, comp, val);
    theta = apply_ebc (theta);
    theta = numbereqns (theta);
    K = start (sparse_sysmat, get(theta, 'neqns'));
    K = assemble (K, conductivity(feb, geom, theta));
    K = assemble (K, surface_transfer(edgefeb, geom, theta));
    F = start (sysvec, get(theta, 'neqns'));
    F = assemble(F, source_loads(feb, geom, theta));
    F = assemble(F, nz_ebc_loads_conductivity(feb, geom, theta));
    F = assemble(F, nz_ebc_loads_surface_transfer(feb, geom, theta));
    F = assemble(F, surface_transfer_loads(edgefeb,geom,theta,amb));
    theta = scatter_sysvec(theta, get(K,'mat')\get(F,'vec'));
    gather(theta,fenode_select(fens,...
        struct('box',[0.6 0.6 0.2 0.2],'inflate', 1e-7)),'values')
    
    % Plot
    if (graphics )
        gv=graphic_viewer;
        gv=reset (gv,[]);
        set(gca,'FontSize', 14)
        T=get(theta,'values');
        dcm=data_colormap(struct('range',[min(T),max(T)],'colormap',jet));
        colorfield=field(struct ('name', ['colorfield'], 'data',...
            map_data(dcm, T)));
        geomT=field(struct ('name', ['geomT'], ...
            'data',[get(geom,'values'), 0.01*get(theta,'values')]));
        for i=1:length (gcells)
            draw(gcells(i), gv, struct ('x',geomT, 'u',0*geomT,...
                'colorfield',colorfield, 'shrink',1));
            draw(gcells(i), gv, struct ('x',geom, 'u',0*geom, ...
                'facecolor','none'));
        end
        xlabel('X [m]')
        ylabel('Y [m]')
        zlabel('Temperature [degrees C]')
    end
    
    nodal_fluxes = field_from_integration_points(feb, geom, theta,  'flux', 1:2);
    elerrs = flux_L2_error (feb, geom, theta, nodal_fluxes);
    total_err=sqrt(sum(elerrs.^2));
    targeterr=sqrt(total_err^2/Targetnel) ;
    
    x=get(geom,'values');
    conn=zeros(length(gcells),length(get(gcells(1),'conn')));
    for j=1:length(gcells)
        conn(j,:)=get(gcells(j),'conn');
    end
    [hcurs, hests] =t3_mesh_sizes(conn,x,targeterr,elerrs,convergence_rate);
    
    [fens,gcells,groups,edge_gcells,edge_groups] ...
        = targe2_mesher_adapt(Region_definition,conn,x,hests,1.0,Mesh_options);
    
end