disp('Taut wire: statics,  uniform load (128-b)');
L=6;
P=4;
q0= 0.1;
q =@(x)(q0);% This is consistent now with the sign convention in the textbook
n=3; % number of elements
node_shift=(+1)*L/n/5; % by how much should the interior node be shifted?
% Mesh
[fens,gcells]= block1d(L,n, 1.0);
nen=length(fens);
[fens,gcells] = L2_to_L3(fens,gcells, []); 
for i=nen+1:length(fens);
    x=get(fens(i),'xyz' );
    fens(i)=set(fens(i),'xyz',x+node_shift);
end 
% Finite element block
feb = feblock_defor_taut_wire(struct ('mater',mater,...
    'gcells',gcells,...
    'integration_rule',gauss_rule(1,4),...
    'P',P));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 1, 'fens',fens));
% Define the displacement field
w   = 0*clone(geom,'w');
% Apply EBC's
fenids=[1,n+1]; prescribed=[1,1]; component=[1,1]; val=[0,0];
w   = set_ebc(w, fenids, prescribed, component, val);
w   = apply_ebc (w);
% Number equations
w   = numbereqns (w);
% Assemble the system matrix
K = start (dense_sysmat, get(w, 'neqns'));
K = assemble (K, stiffness(feb, geom, w));
% Load
fi = force_intensity(struct ('magn',q));
F = start (sysvec, get(w, 'neqns'));
F = assemble (F, body_loads(feb, geom, w, fi));
% Solve
w = scatter_sysvec(w, get(K,'mat')\get(F,'vec'));
% Plot

figure; hold on;
    plot(get(geom,'values'),0*get(geom,'values'),'k-o','linewidth',3);
xlabel('x'),ylabel('Mesh')

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:length(gcells)
    ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
    iw=isoparamipol1d(gcells(j),pc,gather(w,get(gcells(j),'conn'),'values'));
    plot(ix/L,iw,'r-','linewidth',3);hold on
%     x=ix;
%     plot(x/L,(P/q(0)/L^2)*q(0)/(2*P)*x.*(L-x)-(P/q(0)/L^2),'k:','linewidth',3);
end
x=(pc+1)/2*L;
plot(x/L,q(0)/(2*P)*x.*(L-x),'k-','linewidth',3);hold on
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('w')

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:length(gcells)
    ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
    iw=isoparamipol1d(gcells(j),pc,gather(w,get(gcells(j),'conn'),'values'));
    x=ix;
    plot(ix/L,q(0)/(2*P)*x.*(L-x)-iw,'r-','linewidth',3);hold on
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('w_{ex}-w')


figure; hold on;
pc=linspace(-1,+1,100);
for j=1:length(gcells)
    ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
    iwp=isoparamipol1ddersp(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'),gather(w,get(gcells(j),'conn'),'values'));
    plot(ix/L,P*iwp,'r-','linewidth',3);hold on
    x=ix;
    plot(x/L,P*(q(0)/(2*P)*(L-2*x)),'k:','linewidth',3);
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('Pw^{\prime}')

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:length(gcells)
    ix=isoparamipol1d(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'));
    iwp=isoparamipol1ddersp(gcells(j),pc,gather(geom,get(gcells(j),'conn'),'values'),gather(w,get(gcells(j),'conn'),'values'));
    x=ix;
    plot(ix/L,P*(q(0)/(2*P)*(L-2*x))-P*iwp,'r-','linewidth',3);hold on
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('Pw_{ex}^{\prime}-Pw^{\prime}')
