%matrix2latex   Print a matrix in LaTeX tabular format.
%   matrix2latex(M) prints out the numeric matrix M in a LaTeX tabular
%   format. The '&' character appears between entries in a row, '\\'
%   is appended to the ends of rows.
%
%   Copyright 2008 by Petr Krysl
% 
function s = matrix2latex(M,options)
    if (~exist('options','var'))
        options.dummy = 0;
    end
    precision = 2;
    if (isfield(options,'precision'))
        precision=options.precision;
    end
    separator = '';
    if (isfield(options,'separator'))
        separator=options.separator;
    end
    symbol = [];
    if (isfield(options,'symbol'))
        symbol=options.symbol;
    end
    zerotolerance = eps;
    if (isfield(options,'zerotolerance'))
        zerotolerance=options.zerotolerance;
    end
    bracket = [];
    if (isfield(options,'bracket'))
        bracket=options.bracket;
    end
    
    if ndims(M) > 2
        error('Works only for 2D arrays.')
    end

    % Extend the format specifiers.
    [m,n] = size(M);
    
    if (~isempty(bracket))
        S=['\left[' ];
    end
    S=[S '\begin{array}{' sprintf('%c',repmat('c',1,n)) '}'   ];

    for i=1:m
        for j=1:n-1
            S=[S  str(M(i,j))  separator ' & ' ];
        end
        S=[S  str(M(i,n))  ' \\' ];
    end

    S=[S '\end{array}' sprintf('\n')];
    if (~isempty(bracket))
        S=[S '\right]' ];
    end
    
    % Display or output?
    if nargout==0
        disp(S)
    else
        s = S;
    end
    
    function String =str(Element)
        if (isempty(symbol))
            if isa(Element,'double')
                String =num2str(Element, precision);
            else
                String =char(Element);
            end
        else
            if (abs(Element)>Zerotolerance)
                String =symbol;
            else
                String ='';
            end
        end
    end
end
